# coding: utf-8

# flake8: noqa
"""
    用户全部 API 文档

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from ZSGF.Client.models.access_token_list_result import AccessTokenListResult
from ZSGF.Client.models.access_token_list_result_api_response import AccessTokenListResultApiResponse
from ZSGF.Client.models.access_token_post_request import AccessTokenPostRequest
from ZSGF.Client.models.access_token_put_request import AccessTokenPutRequest
from ZSGF.Client.models.alipay_create_order_page_pay_request import AlipayCreateOrderPagePayRequest
from ZSGF.Client.models.alipay_create_order_request import AlipayCreateOrderRequest
from ZSGF.Client.models.alipay_create_order_wap_pay_request import AlipayCreateOrderWapPayRequest
from ZSGF.Client.models.alipay_trade_query_response import AlipayTradeQueryResponse
from ZSGF.Client.models.alipay_trade_query_response_api_response import AlipayTradeQueryResponseApiResponse
from ZSGF.Client.models.alipay_trade_refund_response import AlipayTradeRefundResponse
from ZSGF.Client.models.alipay_trade_refund_response_api_response import AlipayTradeRefundResponseApiResponse
from ZSGF.Client.models.app_info_item import AppInfoItem
from ZSGF.Client.models.app_info_result import AppInfoResult
from ZSGF.Client.models.app_info_result_api_response import AppInfoResultApiResponse
from ZSGF.Client.models.app_property import AppProperty
from ZSGF.Client.models.app_user_consent_model import AppUserConsentModel
from ZSGF.Client.models.app_user_consent_model_list_api_response import AppUserConsentModelListApiResponse
from ZSGF.Client.models.app_user_reset_email_request import AppUserResetEmailRequest
from ZSGF.Client.models.app_user_reset_phone_request import AppUserResetPhoneRequest
from ZSGF.Client.models.app_user_reset_pwd_request import AppUserResetPwdRequest
from ZSGF.Client.models.authorize_result import AuthorizeResult
from ZSGF.Client.models.authorize_result_api_response import AuthorizeResultApiResponse
from ZSGF.Client.models.bk_agent_resp_info import BkAgentRespInfo
from ZSGF.Client.models.boolean_api_response import BooleanApiResponse
from ZSGF.Client.models.charge_info import ChargeInfo
from ZSGF.Client.models.common_friend_model import CommonFriendModel
from ZSGF.Client.models.contribute_detail import ContributeDetail
from ZSGF.Client.models.create_order_request import CreateOrderRequest
from ZSGF.Client.models.create_order_result import CreateOrderResult
from ZSGF.Client.models.create_order_result_api_response import CreateOrderResultApiResponse
from ZSGF.Client.models.currency_consume_request import CurrencyConsumeRequest
from ZSGF.Client.models.currency_transaction import CurrencyTransaction
from ZSGF.Client.models.directory_item import DirectoryItem
from ZSGF.Client.models.email_sign_in_request import EmailSignInRequest
from ZSGF.Client.models.email_sign_up_request import EmailSignUpRequest
from ZSGF.Client.models.enterprise_pay_info import EnterprisePayInfo
from ZSGF.Client.models.exchange_currency_request import ExchangeCurrencyRequest
from ZSGF.Client.models.external_account_bind_request import ExternalAccountBindRequest
from ZSGF.Client.models.external_account_put_request import ExternalAccountPutRequest
from ZSGF.Client.models.external_account_sign_in_request import ExternalAccountSignInRequest
from ZSGF.Client.models.file_item import FileItem
from ZSGF.Client.models.file_list_result import FileListResult
from ZSGF.Client.models.file_list_result_api_response import FileListResultApiResponse
from ZSGF.Client.models.follower_model import FollowerModel
from ZSGF.Client.models.follower_put_model import FollowerPutModel
from ZSGF.Client.models.fulfillment_detail import FulfillmentDetail
from ZSGF.Client.models.geo_location import GeoLocation
from ZSGF.Client.models.geo_location_model import GeoLocationModel
from ZSGF.Client.models.geo_location_model_api_response import GeoLocationModelApiResponse
from ZSGF.Client.models.geo_location_response_model import GeoLocationResponseModel
from ZSGF.Client.models.get_user_profile_result import GetUserProfileResult
from ZSGF.Client.models.get_user_profile_result_api_response import GetUserProfileResultApiResponse
from ZSGF.Client.models.goods_detail import GoodsDetail
from ZSGF.Client.models.grant_request import GrantRequest
from ZSGF.Client.models.grant_result import GrantResult
from ZSGF.Client.models.grant_result_api_response import GrantResultApiResponse
from ZSGF.Client.models.hb_fq_pay_info import HbFqPayInfo
from ZSGF.Client.models.int64_api_response import Int64ApiResponse
from ZSGF.Client.models.intact_charge_info import IntactChargeInfo
from ZSGF.Client.models.my_sql_geometry import MySqlGeometry
from ZSGF.Client.models.object_api_response import ObjectApiResponse
from ZSGF.Client.models.object_list_api_response import ObjectListApiResponse
from ZSGF.Client.models.order import Order
from ZSGF.Client.models.order_api_response import OrderApiResponse
from ZSGF.Client.models.order_list_result import OrderListResult
from ZSGF.Client.models.order_list_result_api_response import OrderListResultApiResponse
from ZSGF.Client.models.payment_info_with_id import PaymentInfoWithId
from ZSGF.Client.models.phone_sign_in_request import PhoneSignInRequest
from ZSGF.Client.models.phone_sign_up_request import PhoneSignUpRequest
from ZSGF.Client.models.preset_pay_tool_info import PresetPayToolInfo
from ZSGF.Client.models.profile_result import ProfileResult
from ZSGF.Client.models.profile_result_api_response import ProfileResultApiResponse
from ZSGF.Client.models.qr_code_pre_sign_in_request import QRCodePreSignInRequest
from ZSGF.Client.models.qr_code_scan_request import QRCodeScanRequest
from ZSGF.Client.models.qr_code_sign_in_request import QRCodeSignInRequest
from ZSGF.Client.models.qr_code_sign_up_request import QRCodeSignUpRequest
from ZSGF.Client.models.recharge_point_request import RechargePointRequest
from ZSGF.Client.models.recommend_friend import RecommendFriend
from ZSGF.Client.models.refund_charge_info import RefundChargeInfo
from ZSGF.Client.models.refund_sub_fee import RefundSubFee
from ZSGF.Client.models.return_page_notify_request import ReturnPageNotifyRequest
from ZSGF.Client.models.send_email_code_request import SendEmailCodeRequest
from ZSGF.Client.models.send_sms_code_request import SendSMSCodeRequest
from ZSGF.Client.models.setup_code import SetupCode
from ZSGF.Client.models.setup_code_api_response import SetupCodeApiResponse
from ZSGF.Client.models.sign_in_request import SignInRequest
from ZSGF.Client.models.sign_up_request import SignUpRequest
from ZSGF.Client.models.storage_list_result import StorageListResult
from ZSGF.Client.models.storage_list_result_api_response import StorageListResultApiResponse
from ZSGF.Client.models.string_api_response import StringApiResponse
from ZSGF.Client.models.sub_fee import SubFee
from ZSGF.Client.models.tap_pay_info import TapPayInfo
from ZSGF.Client.models.token_model import TokenModel
from ZSGF.Client.models.token_model_api_response import TokenModelApiResponse
from ZSGF.Client.models.trade_fund_bill import TradeFundBill
from ZSGF.Client.models.trade_settle_detail import TradeSettleDetail
from ZSGF.Client.models.trade_settle_info import TradeSettleInfo
from ZSGF.Client.models.union_id_sign_in_request import UnionIDSignInRequest
from ZSGF.Client.models.union_id_sign_up_request import UnionIDSignUpRequest
from ZSGF.Client.models.update_profile_request import UpdateProfileRequest
from ZSGF.Client.models.user import User
from ZSGF.Client.models.user_access_token import UserAccessToken
from ZSGF.Client.models.user_common_interests_result import UserCommonInterestsResult
from ZSGF.Client.models.user_common_interests_result_api_response import UserCommonInterestsResultApiResponse
from ZSGF.Client.models.user_currency import UserCurrency
from ZSGF.Client.models.user_currency_currency_trans_result import UserCurrencyCurrencyTransResult
from ZSGF.Client.models.user_currency_currency_trans_result_api_response import UserCurrencyCurrencyTransResultApiResponse
from ZSGF.Client.models.user_currency_list_api_response import UserCurrencyListApiResponse
from ZSGF.Client.models.user_followers_result import UserFollowersResult
from ZSGF.Client.models.user_followers_result_api_response import UserFollowersResultApiResponse
from ZSGF.Client.models.user_friends_near_by_result import UserFriendsNearByResult
from ZSGF.Client.models.user_friends_near_by_result_api_response import UserFriendsNearByResultApiResponse
from ZSGF.Client.models.user_location_post_result import UserLocationPostResult
from ZSGF.Client.models.user_location_post_result_api_response import UserLocationPostResultApiResponse
from ZSGF.Client.models.user_locations_result import UserLocationsResult
from ZSGF.Client.models.user_locations_result_api_response import UserLocationsResultApiResponse
from ZSGF.Client.models.user_logins import UserLogins
from ZSGF.Client.models.user_logins_list_api_response import UserLoginsListApiResponse
from ZSGF.Client.models.user_mutual_followers_result import UserMutualFollowersResult
from ZSGF.Client.models.user_mutual_followers_result_api_response import UserMutualFollowersResultApiResponse
from ZSGF.Client.models.user_mutual_followings_result import UserMutualFollowingsResult
from ZSGF.Client.models.user_mutual_followings_result_api_response import UserMutualFollowingsResultApiResponse
from ZSGF.Client.models.user_profile_result import UserProfileResult
from ZSGF.Client.models.user_profile_result_api_response import UserProfileResultApiResponse
from ZSGF.Client.models.user_qr_code_scan_result import UserQRCodeScanResult
from ZSGF.Client.models.user_qr_code_scan_result_api_response import UserQRCodeScanResultApiResponse
from ZSGF.Client.models.voucher_detail import VoucherDetail
from ZSGF.Client.models.wechat_js_config_result import WechatJSConfigResult
from ZSGF.Client.models.wechat_js_config_result_api_response import WechatJSConfigResultApiResponse



# coding: utf-8

"""
    用户全部 API 文档

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from ZSGF.Client.models.preset_pay_tool_info import PresetPayToolInfo
from ZSGF.Client.models.refund_charge_info import RefundChargeInfo
from ZSGF.Client.models.trade_fund_bill import TradeFundBill
from ZSGF.Client.models.voucher_detail import VoucherDetail
from typing import Optional, Set
from typing_extensions import Self

class AlipayTradeRefundResponse(BaseModel):
    """
    AlipayTradeRefundResponse
    """ # noqa: E501
    code: Optional[StrictStr] = None
    msg: Optional[StrictStr] = None
    sub_code: Optional[StrictStr] = Field(default=None, alias="subCode")
    sub_msg: Optional[StrictStr] = Field(default=None, alias="subMsg")
    body: Optional[StrictStr] = None
    is_error: Optional[StrictBool] = Field(default=None, alias="isError")
    buyer_logon_id: Optional[StrictStr] = Field(default=None, alias="buyerLogonId")
    buyer_open_id: Optional[StrictStr] = Field(default=None, alias="buyerOpenId")
    buyer_user_id: Optional[StrictStr] = Field(default=None, alias="buyerUserId")
    fund_change: Optional[StrictStr] = Field(default=None, alias="fundChange")
    gmt_refund_pay: Optional[StrictStr] = Field(default=None, alias="gmtRefundPay")
    has_deposit_back: Optional[StrictStr] = Field(default=None, alias="hasDepositBack")
    open_id: Optional[StrictStr] = Field(default=None, alias="openId")
    out_trade_no: Optional[StrictStr] = Field(default=None, alias="outTradeNo")
    pre_auth_cancel_fee: Optional[StrictStr] = Field(default=None, alias="preAuthCancelFee")
    present_refund_buyer_amount: Optional[StrictStr] = Field(default=None, alias="presentRefundBuyerAmount")
    present_refund_discount_amount: Optional[StrictStr] = Field(default=None, alias="presentRefundDiscountAmount")
    present_refund_mdiscount_amount: Optional[StrictStr] = Field(default=None, alias="presentRefundMdiscountAmount")
    refund_charge_amount: Optional[StrictStr] = Field(default=None, alias="refundChargeAmount")
    refund_charge_info_list: Optional[List[RefundChargeInfo]] = Field(default=None, alias="refundChargeInfoList")
    refund_currency: Optional[StrictStr] = Field(default=None, alias="refundCurrency")
    refund_detail_item_list: Optional[List[TradeFundBill]] = Field(default=None, alias="refundDetailItemList")
    refund_fee: Optional[StrictStr] = Field(default=None, alias="refundFee")
    refund_hyb_amount: Optional[StrictStr] = Field(default=None, alias="refundHybAmount")
    refund_preset_paytool_list: Optional[PresetPayToolInfo] = Field(default=None, alias="refundPresetPaytoolList")
    refund_settlement_id: Optional[StrictStr] = Field(default=None, alias="refundSettlementId")
    refund_voucher_detail_list: Optional[List[VoucherDetail]] = Field(default=None, alias="refundVoucherDetailList")
    send_back_fee: Optional[StrictStr] = Field(default=None, alias="sendBackFee")
    store_name: Optional[StrictStr] = Field(default=None, alias="storeName")
    trade_no: Optional[StrictStr] = Field(default=None, alias="tradeNo")
    __properties: ClassVar[List[str]] = ["code", "msg", "subCode", "subMsg", "body", "isError", "buyerLogonId", "buyerOpenId", "buyerUserId", "fundChange", "gmtRefundPay", "hasDepositBack", "openId", "outTradeNo", "preAuthCancelFee", "presentRefundBuyerAmount", "presentRefundDiscountAmount", "presentRefundMdiscountAmount", "refundChargeAmount", "refundChargeInfoList", "refundCurrency", "refundDetailItemList", "refundFee", "refundHybAmount", "refundPresetPaytoolList", "refundSettlementId", "refundVoucherDetailList", "sendBackFee", "storeName", "tradeNo"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AlipayTradeRefundResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "is_error",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in refund_charge_info_list (list)
        _items = []
        if self.refund_charge_info_list:
            for _item_refund_charge_info_list in self.refund_charge_info_list:
                if _item_refund_charge_info_list:
                    _items.append(_item_refund_charge_info_list.to_dict())
            _dict['refundChargeInfoList'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in refund_detail_item_list (list)
        _items = []
        if self.refund_detail_item_list:
            for _item_refund_detail_item_list in self.refund_detail_item_list:
                if _item_refund_detail_item_list:
                    _items.append(_item_refund_detail_item_list.to_dict())
            _dict['refundDetailItemList'] = _items
        # override the default output from pydantic by calling `to_dict()` of refund_preset_paytool_list
        if self.refund_preset_paytool_list:
            _dict['refundPresetPaytoolList'] = self.refund_preset_paytool_list.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in refund_voucher_detail_list (list)
        _items = []
        if self.refund_voucher_detail_list:
            for _item_refund_voucher_detail_list in self.refund_voucher_detail_list:
                if _item_refund_voucher_detail_list:
                    _items.append(_item_refund_voucher_detail_list.to_dict())
            _dict['refundVoucherDetailList'] = _items
        # set to None if code (nullable) is None
        # and model_fields_set contains the field
        if self.code is None and "code" in self.model_fields_set:
            _dict['code'] = None

        # set to None if msg (nullable) is None
        # and model_fields_set contains the field
        if self.msg is None and "msg" in self.model_fields_set:
            _dict['msg'] = None

        # set to None if sub_code (nullable) is None
        # and model_fields_set contains the field
        if self.sub_code is None and "sub_code" in self.model_fields_set:
            _dict['subCode'] = None

        # set to None if sub_msg (nullable) is None
        # and model_fields_set contains the field
        if self.sub_msg is None and "sub_msg" in self.model_fields_set:
            _dict['subMsg'] = None

        # set to None if body (nullable) is None
        # and model_fields_set contains the field
        if self.body is None and "body" in self.model_fields_set:
            _dict['body'] = None

        # set to None if buyer_logon_id (nullable) is None
        # and model_fields_set contains the field
        if self.buyer_logon_id is None and "buyer_logon_id" in self.model_fields_set:
            _dict['buyerLogonId'] = None

        # set to None if buyer_open_id (nullable) is None
        # and model_fields_set contains the field
        if self.buyer_open_id is None and "buyer_open_id" in self.model_fields_set:
            _dict['buyerOpenId'] = None

        # set to None if buyer_user_id (nullable) is None
        # and model_fields_set contains the field
        if self.buyer_user_id is None and "buyer_user_id" in self.model_fields_set:
            _dict['buyerUserId'] = None

        # set to None if fund_change (nullable) is None
        # and model_fields_set contains the field
        if self.fund_change is None and "fund_change" in self.model_fields_set:
            _dict['fundChange'] = None

        # set to None if gmt_refund_pay (nullable) is None
        # and model_fields_set contains the field
        if self.gmt_refund_pay is None and "gmt_refund_pay" in self.model_fields_set:
            _dict['gmtRefundPay'] = None

        # set to None if has_deposit_back (nullable) is None
        # and model_fields_set contains the field
        if self.has_deposit_back is None and "has_deposit_back" in self.model_fields_set:
            _dict['hasDepositBack'] = None

        # set to None if open_id (nullable) is None
        # and model_fields_set contains the field
        if self.open_id is None and "open_id" in self.model_fields_set:
            _dict['openId'] = None

        # set to None if out_trade_no (nullable) is None
        # and model_fields_set contains the field
        if self.out_trade_no is None and "out_trade_no" in self.model_fields_set:
            _dict['outTradeNo'] = None

        # set to None if pre_auth_cancel_fee (nullable) is None
        # and model_fields_set contains the field
        if self.pre_auth_cancel_fee is None and "pre_auth_cancel_fee" in self.model_fields_set:
            _dict['preAuthCancelFee'] = None

        # set to None if present_refund_buyer_amount (nullable) is None
        # and model_fields_set contains the field
        if self.present_refund_buyer_amount is None and "present_refund_buyer_amount" in self.model_fields_set:
            _dict['presentRefundBuyerAmount'] = None

        # set to None if present_refund_discount_amount (nullable) is None
        # and model_fields_set contains the field
        if self.present_refund_discount_amount is None and "present_refund_discount_amount" in self.model_fields_set:
            _dict['presentRefundDiscountAmount'] = None

        # set to None if present_refund_mdiscount_amount (nullable) is None
        # and model_fields_set contains the field
        if self.present_refund_mdiscount_amount is None and "present_refund_mdiscount_amount" in self.model_fields_set:
            _dict['presentRefundMdiscountAmount'] = None

        # set to None if refund_charge_amount (nullable) is None
        # and model_fields_set contains the field
        if self.refund_charge_amount is None and "refund_charge_amount" in self.model_fields_set:
            _dict['refundChargeAmount'] = None

        # set to None if refund_charge_info_list (nullable) is None
        # and model_fields_set contains the field
        if self.refund_charge_info_list is None and "refund_charge_info_list" in self.model_fields_set:
            _dict['refundChargeInfoList'] = None

        # set to None if refund_currency (nullable) is None
        # and model_fields_set contains the field
        if self.refund_currency is None and "refund_currency" in self.model_fields_set:
            _dict['refundCurrency'] = None

        # set to None if refund_detail_item_list (nullable) is None
        # and model_fields_set contains the field
        if self.refund_detail_item_list is None and "refund_detail_item_list" in self.model_fields_set:
            _dict['refundDetailItemList'] = None

        # set to None if refund_fee (nullable) is None
        # and model_fields_set contains the field
        if self.refund_fee is None and "refund_fee" in self.model_fields_set:
            _dict['refundFee'] = None

        # set to None if refund_hyb_amount (nullable) is None
        # and model_fields_set contains the field
        if self.refund_hyb_amount is None and "refund_hyb_amount" in self.model_fields_set:
            _dict['refundHybAmount'] = None

        # set to None if refund_settlement_id (nullable) is None
        # and model_fields_set contains the field
        if self.refund_settlement_id is None and "refund_settlement_id" in self.model_fields_set:
            _dict['refundSettlementId'] = None

        # set to None if refund_voucher_detail_list (nullable) is None
        # and model_fields_set contains the field
        if self.refund_voucher_detail_list is None and "refund_voucher_detail_list" in self.model_fields_set:
            _dict['refundVoucherDetailList'] = None

        # set to None if send_back_fee (nullable) is None
        # and model_fields_set contains the field
        if self.send_back_fee is None and "send_back_fee" in self.model_fields_set:
            _dict['sendBackFee'] = None

        # set to None if store_name (nullable) is None
        # and model_fields_set contains the field
        if self.store_name is None and "store_name" in self.model_fields_set:
            _dict['storeName'] = None

        # set to None if trade_no (nullable) is None
        # and model_fields_set contains the field
        if self.trade_no is None and "trade_no" in self.model_fields_set:
            _dict['tradeNo'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AlipayTradeRefundResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "code": obj.get("code"),
            "msg": obj.get("msg"),
            "subCode": obj.get("subCode"),
            "subMsg": obj.get("subMsg"),
            "body": obj.get("body"),
            "isError": obj.get("isError"),
            "buyerLogonId": obj.get("buyerLogonId"),
            "buyerOpenId": obj.get("buyerOpenId"),
            "buyerUserId": obj.get("buyerUserId"),
            "fundChange": obj.get("fundChange"),
            "gmtRefundPay": obj.get("gmtRefundPay"),
            "hasDepositBack": obj.get("hasDepositBack"),
            "openId": obj.get("openId"),
            "outTradeNo": obj.get("outTradeNo"),
            "preAuthCancelFee": obj.get("preAuthCancelFee"),
            "presentRefundBuyerAmount": obj.get("presentRefundBuyerAmount"),
            "presentRefundDiscountAmount": obj.get("presentRefundDiscountAmount"),
            "presentRefundMdiscountAmount": obj.get("presentRefundMdiscountAmount"),
            "refundChargeAmount": obj.get("refundChargeAmount"),
            "refundChargeInfoList": [RefundChargeInfo.from_dict(_item) for _item in obj["refundChargeInfoList"]] if obj.get("refundChargeInfoList") is not None else None,
            "refundCurrency": obj.get("refundCurrency"),
            "refundDetailItemList": [TradeFundBill.from_dict(_item) for _item in obj["refundDetailItemList"]] if obj.get("refundDetailItemList") is not None else None,
            "refundFee": obj.get("refundFee"),
            "refundHybAmount": obj.get("refundHybAmount"),
            "refundPresetPaytoolList": PresetPayToolInfo.from_dict(obj["refundPresetPaytoolList"]) if obj.get("refundPresetPaytoolList") is not None else None,
            "refundSettlementId": obj.get("refundSettlementId"),
            "refundVoucherDetailList": [VoucherDetail.from_dict(_item) for _item in obj["refundVoucherDetailList"]] if obj.get("refundVoucherDetailList") is not None else None,
            "sendBackFee": obj.get("sendBackFee"),
            "storeName": obj.get("storeName"),
            "tradeNo": obj.get("tradeNo")
        })
        return _obj





# coding: utf-8

"""
    用户全部 API 文档

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from ZSGF.Client.models.contribute_detail import ContributeDetail
from typing import Optional, Set
from typing_extensions import Self

class VoucherDetail(BaseModel):
    """
    VoucherDetail
    """ # noqa: E501
    amount: Optional[StrictStr] = None
    id: Optional[StrictStr] = None
    memo: Optional[StrictStr] = None
    merchant_contribute: Optional[StrictStr] = Field(default=None, alias="merchantContribute")
    name: Optional[StrictStr] = None
    other_contribute: Optional[StrictStr] = Field(default=None, alias="otherContribute")
    other_contribute_detail: Optional[List[ContributeDetail]] = Field(default=None, alias="otherContributeDetail")
    purchase_ant_contribute: Optional[StrictStr] = Field(default=None, alias="purchaseAntContribute")
    purchase_buyer_contribute: Optional[StrictStr] = Field(default=None, alias="purchaseBuyerContribute")
    purchase_merchant_contribute: Optional[StrictStr] = Field(default=None, alias="purchaseMerchantContribute")
    template_id: Optional[StrictStr] = Field(default=None, alias="templateId")
    type: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["amount", "id", "memo", "merchantContribute", "name", "otherContribute", "otherContributeDetail", "purchaseAntContribute", "purchaseBuyerContribute", "purchaseMerchantContribute", "templateId", "type"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of VoucherDetail from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in other_contribute_detail (list)
        _items = []
        if self.other_contribute_detail:
            for _item_other_contribute_detail in self.other_contribute_detail:
                if _item_other_contribute_detail:
                    _items.append(_item_other_contribute_detail.to_dict())
            _dict['otherContributeDetail'] = _items
        # set to None if amount (nullable) is None
        # and model_fields_set contains the field
        if self.amount is None and "amount" in self.model_fields_set:
            _dict['amount'] = None

        # set to None if id (nullable) is None
        # and model_fields_set contains the field
        if self.id is None and "id" in self.model_fields_set:
            _dict['id'] = None

        # set to None if memo (nullable) is None
        # and model_fields_set contains the field
        if self.memo is None and "memo" in self.model_fields_set:
            _dict['memo'] = None

        # set to None if merchant_contribute (nullable) is None
        # and model_fields_set contains the field
        if self.merchant_contribute is None and "merchant_contribute" in self.model_fields_set:
            _dict['merchantContribute'] = None

        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict['name'] = None

        # set to None if other_contribute (nullable) is None
        # and model_fields_set contains the field
        if self.other_contribute is None and "other_contribute" in self.model_fields_set:
            _dict['otherContribute'] = None

        # set to None if other_contribute_detail (nullable) is None
        # and model_fields_set contains the field
        if self.other_contribute_detail is None and "other_contribute_detail" in self.model_fields_set:
            _dict['otherContributeDetail'] = None

        # set to None if purchase_ant_contribute (nullable) is None
        # and model_fields_set contains the field
        if self.purchase_ant_contribute is None and "purchase_ant_contribute" in self.model_fields_set:
            _dict['purchaseAntContribute'] = None

        # set to None if purchase_buyer_contribute (nullable) is None
        # and model_fields_set contains the field
        if self.purchase_buyer_contribute is None and "purchase_buyer_contribute" in self.model_fields_set:
            _dict['purchaseBuyerContribute'] = None

        # set to None if purchase_merchant_contribute (nullable) is None
        # and model_fields_set contains the field
        if self.purchase_merchant_contribute is None and "purchase_merchant_contribute" in self.model_fields_set:
            _dict['purchaseMerchantContribute'] = None

        # set to None if template_id (nullable) is None
        # and model_fields_set contains the field
        if self.template_id is None and "template_id" in self.model_fields_set:
            _dict['templateId'] = None

        # set to None if type (nullable) is None
        # and model_fields_set contains the field
        if self.type is None and "type" in self.model_fields_set:
            _dict['type'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of VoucherDetail from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "amount": obj.get("amount"),
            "id": obj.get("id"),
            "memo": obj.get("memo"),
            "merchantContribute": obj.get("merchantContribute"),
            "name": obj.get("name"),
            "otherContribute": obj.get("otherContribute"),
            "otherContributeDetail": [ContributeDetail.from_dict(_item) for _item in obj["otherContributeDetail"]] if obj.get("otherContributeDetail") is not None else None,
            "purchaseAntContribute": obj.get("purchaseAntContribute"),
            "purchaseBuyerContribute": obj.get("purchaseBuyerContribute"),
            "purchaseMerchantContribute": obj.get("purchaseMerchantContribute"),
            "templateId": obj.get("templateId"),
            "type": obj.get("type")
        })
        return _obj





# coding: utf-8

"""
    用户全部 API 文档

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictInt, StrictStr
from typing import Optional
from typing_extensions import Annotated
from ZSGF.Client.models.create_order_request import CreateOrderRequest
from ZSGF.Client.models.create_order_result_api_response import CreateOrderResultApiResponse
from ZSGF.Client.models.order_api_response import OrderApiResponse
from ZSGF.Client.models.order_list_result_api_response import OrderListResultApiResponse

from ZSGF.Client.api_client import ApiClient, RequestSerialized
from ZSGF.Client.api_response import ApiResponse
from ZSGF.Client.rest import RESTResponseType


class OrderApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def order(
        self,
        id: Annotated[StrictInt, Field(description="订单ID")],
        app_key: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> OrderApiResponse:
        """获取订单详情

        根据订单ID获取订单详情

        :param id: 订单ID (required)
        :type id: int
        :param app_key: (required)
        :type app_key: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._order_serialize(
            id=id,
            app_key=app_key,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "OrderApiResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def order_with_http_info(
        self,
        id: Annotated[StrictInt, Field(description="订单ID")],
        app_key: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[OrderApiResponse]:
        """获取订单详情

        根据订单ID获取订单详情

        :param id: 订单ID (required)
        :type id: int
        :param app_key: (required)
        :type app_key: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._order_serialize(
            id=id,
            app_key=app_key,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "OrderApiResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def order_without_preload_content(
        self,
        id: Annotated[StrictInt, Field(description="订单ID")],
        app_key: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """获取订单详情

        根据订单ID获取订单详情

        :param id: 订单ID (required)
        :type id: int
        :param app_key: (required)
        :type app_key: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._order_serialize(
            id=id,
            app_key=app_key,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "OrderApiResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _order_serialize(
        self,
        id,
        app_key,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        if app_key is not None:
            _path_params['appKey'] = app_key
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'Bearer'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/Order/{appKey}/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def order_create(
        self,
        app_key: StrictStr,
        create_order_request: Annotated[Optional[CreateOrderRequest], Field(description="订单创建请求")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> CreateOrderResultApiResponse:
        """创建订单

        根据请求参数创建订单

        :param app_key: (required)
        :type app_key: str
        :param create_order_request: 订单创建请求
        :type create_order_request: CreateOrderRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._order_create_serialize(
            app_key=app_key,
            create_order_request=create_order_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CreateOrderResultApiResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def order_create_with_http_info(
        self,
        app_key: StrictStr,
        create_order_request: Annotated[Optional[CreateOrderRequest], Field(description="订单创建请求")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[CreateOrderResultApiResponse]:
        """创建订单

        根据请求参数创建订单

        :param app_key: (required)
        :type app_key: str
        :param create_order_request: 订单创建请求
        :type create_order_request: CreateOrderRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._order_create_serialize(
            app_key=app_key,
            create_order_request=create_order_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CreateOrderResultApiResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def order_create_without_preload_content(
        self,
        app_key: StrictStr,
        create_order_request: Annotated[Optional[CreateOrderRequest], Field(description="订单创建请求")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """创建订单

        根据请求参数创建订单

        :param app_key: (required)
        :type app_key: str
        :param create_order_request: 订单创建请求
        :type create_order_request: CreateOrderRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._order_create_serialize(
            app_key=app_key,
            create_order_request=create_order_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CreateOrderResultApiResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _order_create_serialize(
        self,
        app_key,
        create_order_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if app_key is not None:
            _path_params['appKey'] = app_key
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if create_order_request is not None:
            _body_params = create_order_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json-patch+json', 
                        'application/json', 
                        'text/json', 
                        'application/*+json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'Bearer'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/Order/{appKey}/Create',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def orders(
        self,
        app_key: StrictStr,
        status: Annotated[Optional[StrictStr], Field(description="订单状态")] = None,
        order_no: Annotated[Optional[StrictStr], Field(description="系统订单号")] = None,
        trade_no: Annotated[Optional[StrictStr], Field(description="支付平台单号")] = None,
        user_id: Annotated[Optional[StrictInt], Field(description="用户ID")] = None,
        pct_type: Annotated[Optional[StrictStr], Field(description="商品类型")] = None,
        pct_id: Annotated[Optional[StrictStr], Field(description="商品ID")] = None,
        pct_name: Annotated[Optional[StrictStr], Field(description="商品名称")] = None,
        skip: Annotated[Optional[StrictInt], Field(description="跳过的条数")] = None,
        take: Annotated[Optional[StrictInt], Field(description="拉取的条数")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> OrderListResultApiResponse:
        """获取订单列表

        根据查询条件获取订单列表

        :param app_key: (required)
        :type app_key: str
        :param status: 订单状态
        :type status: str
        :param order_no: 系统订单号
        :type order_no: str
        :param trade_no: 支付平台单号
        :type trade_no: str
        :param user_id: 用户ID
        :type user_id: int
        :param pct_type: 商品类型
        :type pct_type: str
        :param pct_id: 商品ID
        :type pct_id: str
        :param pct_name: 商品名称
        :type pct_name: str
        :param skip: 跳过的条数
        :type skip: int
        :param take: 拉取的条数
        :type take: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._orders_serialize(
            app_key=app_key,
            status=status,
            order_no=order_no,
            trade_no=trade_no,
            user_id=user_id,
            pct_type=pct_type,
            pct_id=pct_id,
            pct_name=pct_name,
            skip=skip,
            take=take,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "OrderListResultApiResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def orders_with_http_info(
        self,
        app_key: StrictStr,
        status: Annotated[Optional[StrictStr], Field(description="订单状态")] = None,
        order_no: Annotated[Optional[StrictStr], Field(description="系统订单号")] = None,
        trade_no: Annotated[Optional[StrictStr], Field(description="支付平台单号")] = None,
        user_id: Annotated[Optional[StrictInt], Field(description="用户ID")] = None,
        pct_type: Annotated[Optional[StrictStr], Field(description="商品类型")] = None,
        pct_id: Annotated[Optional[StrictStr], Field(description="商品ID")] = None,
        pct_name: Annotated[Optional[StrictStr], Field(description="商品名称")] = None,
        skip: Annotated[Optional[StrictInt], Field(description="跳过的条数")] = None,
        take: Annotated[Optional[StrictInt], Field(description="拉取的条数")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[OrderListResultApiResponse]:
        """获取订单列表

        根据查询条件获取订单列表

        :param app_key: (required)
        :type app_key: str
        :param status: 订单状态
        :type status: str
        :param order_no: 系统订单号
        :type order_no: str
        :param trade_no: 支付平台单号
        :type trade_no: str
        :param user_id: 用户ID
        :type user_id: int
        :param pct_type: 商品类型
        :type pct_type: str
        :param pct_id: 商品ID
        :type pct_id: str
        :param pct_name: 商品名称
        :type pct_name: str
        :param skip: 跳过的条数
        :type skip: int
        :param take: 拉取的条数
        :type take: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._orders_serialize(
            app_key=app_key,
            status=status,
            order_no=order_no,
            trade_no=trade_no,
            user_id=user_id,
            pct_type=pct_type,
            pct_id=pct_id,
            pct_name=pct_name,
            skip=skip,
            take=take,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "OrderListResultApiResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def orders_without_preload_content(
        self,
        app_key: StrictStr,
        status: Annotated[Optional[StrictStr], Field(description="订单状态")] = None,
        order_no: Annotated[Optional[StrictStr], Field(description="系统订单号")] = None,
        trade_no: Annotated[Optional[StrictStr], Field(description="支付平台单号")] = None,
        user_id: Annotated[Optional[StrictInt], Field(description="用户ID")] = None,
        pct_type: Annotated[Optional[StrictStr], Field(description="商品类型")] = None,
        pct_id: Annotated[Optional[StrictStr], Field(description="商品ID")] = None,
        pct_name: Annotated[Optional[StrictStr], Field(description="商品名称")] = None,
        skip: Annotated[Optional[StrictInt], Field(description="跳过的条数")] = None,
        take: Annotated[Optional[StrictInt], Field(description="拉取的条数")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """获取订单列表

        根据查询条件获取订单列表

        :param app_key: (required)
        :type app_key: str
        :param status: 订单状态
        :type status: str
        :param order_no: 系统订单号
        :type order_no: str
        :param trade_no: 支付平台单号
        :type trade_no: str
        :param user_id: 用户ID
        :type user_id: int
        :param pct_type: 商品类型
        :type pct_type: str
        :param pct_id: 商品ID
        :type pct_id: str
        :param pct_name: 商品名称
        :type pct_name: str
        :param skip: 跳过的条数
        :type skip: int
        :param take: 拉取的条数
        :type take: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._orders_serialize(
            app_key=app_key,
            status=status,
            order_no=order_no,
            trade_no=trade_no,
            user_id=user_id,
            pct_type=pct_type,
            pct_id=pct_id,
            pct_name=pct_name,
            skip=skip,
            take=take,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "OrderListResultApiResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _orders_serialize(
        self,
        app_key,
        status,
        order_no,
        trade_no,
        user_id,
        pct_type,
        pct_id,
        pct_name,
        skip,
        take,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if app_key is not None:
            _path_params['appKey'] = app_key
        # process the query parameters
        if status is not None:
            
            _query_params.append(('status', status))
            
        if order_no is not None:
            
            _query_params.append(('orderNo', order_no))
            
        if trade_no is not None:
            
            _query_params.append(('tradeNo', trade_no))
            
        if user_id is not None:
            
            _query_params.append(('userId', user_id))
            
        if pct_type is not None:
            
            _query_params.append(('pctType', pct_type))
            
        if pct_id is not None:
            
            _query_params.append(('pctId', pct_id))
            
        if pct_name is not None:
            
            _query_params.append(('pctName', pct_name))
            
        if skip is not None:
            
            _query_params.append(('skip', skip))
            
        if take is not None:
            
            _query_params.append(('take', take))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'Bearer'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/Order/{appKey}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    用户全部 API 文档

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class IntactChargeInfo(BaseModel):
    """
    IntactChargeInfo
    """ # noqa: E501
    actual_amount: Optional[StrictStr] = Field(default=None, alias="actualAmount")
    bill_type: Optional[StrictStr] = Field(default=None, alias="billType")
    gmt_pay: Optional[StrictStr] = Field(default=None, alias="gmtPay")
    is_refund: Optional[StrictBool] = Field(default=None, alias="isRefund")
    out_biz_no: Optional[StrictStr] = Field(default=None, alias="outBizNo")
    plan_amount: Optional[StrictStr] = Field(default=None, alias="planAmount")
    product_name: Optional[StrictStr] = Field(default=None, alias="productName")
    service_target: Optional[StrictStr] = Field(default=None, alias="serviceTarget")
    service_type: Optional[StrictStr] = Field(default=None, alias="serviceType")
    status: Optional[StrictStr] = None
    target_account_no: Optional[StrictStr] = Field(default=None, alias="targetAccountNo")
    target_user_id: Optional[StrictStr] = Field(default=None, alias="targetUserId")
    __properties: ClassVar[List[str]] = ["actualAmount", "billType", "gmtPay", "isRefund", "outBizNo", "planAmount", "productName", "serviceTarget", "serviceType", "status", "targetAccountNo", "targetUserId"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of IntactChargeInfo from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if actual_amount (nullable) is None
        # and model_fields_set contains the field
        if self.actual_amount is None and "actual_amount" in self.model_fields_set:
            _dict['actualAmount'] = None

        # set to None if bill_type (nullable) is None
        # and model_fields_set contains the field
        if self.bill_type is None and "bill_type" in self.model_fields_set:
            _dict['billType'] = None

        # set to None if gmt_pay (nullable) is None
        # and model_fields_set contains the field
        if self.gmt_pay is None and "gmt_pay" in self.model_fields_set:
            _dict['gmtPay'] = None

        # set to None if out_biz_no (nullable) is None
        # and model_fields_set contains the field
        if self.out_biz_no is None and "out_biz_no" in self.model_fields_set:
            _dict['outBizNo'] = None

        # set to None if plan_amount (nullable) is None
        # and model_fields_set contains the field
        if self.plan_amount is None and "plan_amount" in self.model_fields_set:
            _dict['planAmount'] = None

        # set to None if product_name (nullable) is None
        # and model_fields_set contains the field
        if self.product_name is None and "product_name" in self.model_fields_set:
            _dict['productName'] = None

        # set to None if service_target (nullable) is None
        # and model_fields_set contains the field
        if self.service_target is None and "service_target" in self.model_fields_set:
            _dict['serviceTarget'] = None

        # set to None if service_type (nullable) is None
        # and model_fields_set contains the field
        if self.service_type is None and "service_type" in self.model_fields_set:
            _dict['serviceType'] = None

        # set to None if status (nullable) is None
        # and model_fields_set contains the field
        if self.status is None and "status" in self.model_fields_set:
            _dict['status'] = None

        # set to None if target_account_no (nullable) is None
        # and model_fields_set contains the field
        if self.target_account_no is None and "target_account_no" in self.model_fields_set:
            _dict['targetAccountNo'] = None

        # set to None if target_user_id (nullable) is None
        # and model_fields_set contains the field
        if self.target_user_id is None and "target_user_id" in self.model_fields_set:
            _dict['targetUserId'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of IntactChargeInfo from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "actualAmount": obj.get("actualAmount"),
            "billType": obj.get("billType"),
            "gmtPay": obj.get("gmtPay"),
            "isRefund": obj.get("isRefund"),
            "outBizNo": obj.get("outBizNo"),
            "planAmount": obj.get("planAmount"),
            "productName": obj.get("productName"),
            "serviceTarget": obj.get("serviceTarget"),
            "serviceType": obj.get("serviceType"),
            "status": obj.get("status"),
            "targetAccountNo": obj.get("targetAccountNo"),
            "targetUserId": obj.get("targetUserId")
        })
        return _obj





# coding: utf-8

"""
    用户全部 API 文档

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Optional, Set
from typing_extensions import Self

class RecommendFriend(BaseModel):
    """
    RecommendFriend
    """ # noqa: E501
    user_id: Optional[StrictInt] = Field(default=None, description="用户ID", alias="userID")
    nick_name: Optional[StrictStr] = Field(default=None, description="昵称", alias="nickName")
    avatar: Optional[StrictStr] = Field(default=None, description="头像")
    gender: Optional[StrictStr] = Field(default=None, description="性别")
    age: Optional[StrictInt] = Field(default=None, description="年龄")
    interest_tags: Optional[StrictStr] = Field(default=None, description="兴趣标签", alias="interestTags")
    location_name: Optional[StrictStr] = Field(default=None, description="位置名称", alias="locationName")
    latitude: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="纬度")
    longitude: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="经度")
    distance: Optional[StrictInt] = Field(default=None, description="距离")
    biography: Optional[StrictStr] = Field(default=None, description="个人简介")
    country: Optional[StrictStr] = Field(default=None, description="国家")
    state: Optional[StrictStr] = Field(default=None, description="省份")
    city: Optional[StrictStr] = Field(default=None, description="城市")
    district: Optional[StrictStr] = Field(default=None, description="区县")
    __properties: ClassVar[List[str]] = ["userID", "nickName", "avatar", "gender", "age", "interestTags", "locationName", "latitude", "longitude", "distance", "biography", "country", "state", "city", "district"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of RecommendFriend from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if nick_name (nullable) is None
        # and model_fields_set contains the field
        if self.nick_name is None and "nick_name" in self.model_fields_set:
            _dict['nickName'] = None

        # set to None if avatar (nullable) is None
        # and model_fields_set contains the field
        if self.avatar is None and "avatar" in self.model_fields_set:
            _dict['avatar'] = None

        # set to None if gender (nullable) is None
        # and model_fields_set contains the field
        if self.gender is None and "gender" in self.model_fields_set:
            _dict['gender'] = None

        # set to None if interest_tags (nullable) is None
        # and model_fields_set contains the field
        if self.interest_tags is None and "interest_tags" in self.model_fields_set:
            _dict['interestTags'] = None

        # set to None if location_name (nullable) is None
        # and model_fields_set contains the field
        if self.location_name is None and "location_name" in self.model_fields_set:
            _dict['locationName'] = None

        # set to None if biography (nullable) is None
        # and model_fields_set contains the field
        if self.biography is None and "biography" in self.model_fields_set:
            _dict['biography'] = None

        # set to None if country (nullable) is None
        # and model_fields_set contains the field
        if self.country is None and "country" in self.model_fields_set:
            _dict['country'] = None

        # set to None if state (nullable) is None
        # and model_fields_set contains the field
        if self.state is None and "state" in self.model_fields_set:
            _dict['state'] = None

        # set to None if city (nullable) is None
        # and model_fields_set contains the field
        if self.city is None and "city" in self.model_fields_set:
            _dict['city'] = None

        # set to None if district (nullable) is None
        # and model_fields_set contains the field
        if self.district is None and "district" in self.model_fields_set:
            _dict['district'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of RecommendFriend from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "userID": obj.get("userID"),
            "nickName": obj.get("nickName"),
            "avatar": obj.get("avatar"),
            "gender": obj.get("gender"),
            "age": obj.get("age"),
            "interestTags": obj.get("interestTags"),
            "locationName": obj.get("locationName"),
            "latitude": obj.get("latitude"),
            "longitude": obj.get("longitude"),
            "distance": obj.get("distance"),
            "biography": obj.get("biography"),
            "country": obj.get("country"),
            "state": obj.get("state"),
            "city": obj.get("city"),
            "district": obj.get("district")
        })
        return _obj


